{% extends "base.html" %}
{% block title %}Error{% end %}
{% block head %}
{% end %}
{% block body %}
<h1 class="ui red header">Error 404... La page que vous cherchez n'existe pas...</h1>
<a class="ui red link" href="/">Retour à la maison</a>
{% end %}
