{% extends "card.html" %}
{% block submenu%}
<a class="item" href="/card">Cartes</a>
<div class="active item">{{card.name}}</div>
{% end %}
{% block body %}
<div class="ui centered card">
    <div class="content">
        <div class="header">
            {{card.name}}
        </div>
        <div class="description">
            Nombre d'entrées analogiques: {{card.nb_input_pins}}
        </div>
        <div class="description">
            Nombre de sorties digitales: {{card.nb_output_pins}}
        </div>
    </div>
    <div class="ui two bottom attached buttons">
        <a class="ui yellow submit button" href="./{{ url_escape(slug)}}/edit"><i class="edit outline icon"></i>Modifier la configuration</a>
        <form class="item ui red button"  action="./{{ url_escape(slug)}}" method="post">
            <input name="_method" type="hidden" value="delete" />
            <button class="ui red submit button" type="submit"><i class="eraser icon"></i>Supprimer</button>
        </form>
    </div>
</div>
{% end %}
