{% extends "device.html" %}
{% block body %}
<h1>Device</h1>
{% if devices is not None %}
{% for device in devices%}
<div class="ui middle aligned animated list">
    <a class="item" href="/device/{{ url_escape(device.name) }}">
        <i class="settings icon"></i>
        <div class="content">
            <div class="header">{{device.name}}</div>
            <div class="description">
                Voir
            </div>
        </div>
    </a>
</div>
{% end %}
{% else %}
<h2>Pas de configuration à l'heure actuelle.</h2>
{% end %}
{% end %}
